import { __decorate } from "tslib";
import { css, html, LitElement, property } from 'lit-element';
export class WcesFormBuilder extends LitElement {
    constructor() {
        super(...arguments);
        this.columnCount = 1;
        this.catalog = new Map();
        this._value = {};
        this._valid = {};
    }
    get elements() {
        var _a;
        return (_a = this.param) === null || _a === void 0 ? void 0 : _a.options.map(param => { var _a; return (_a = this.catalog.get(param.type)) === null || _a === void 0 ? void 0 : _a.create(param); });
    }
    get value() {
        return this._value;
    }
    set value(val) {
        const oldValue = this._value;
        this._value = val;
        this.requestUpdate('value', oldValue);
    }
    onChange(name, value) {
        this.value = {
            ...this.value,
            [name]: value,
        };
        this.dispatchEvent(new CustomEvent('change', { detail: { value: this.value } }));
    }
    get valid() {
        var _a;
        return (_a = this.param) === null || _a === void 0 ? void 0 : _a.options.every(({ name, required }) => this._valid[name] || (!this.value[name] && !required));
    }
    onValidityChange(name, isValid) {
        this._valid = {
            ...this._valid,
            [name]: isValid,
        };
        this.dispatchEvent(new CustomEvent('validityChange', { detail: { value: this.valid } }));
    }
    render() {
        var _a;
        return html `
      <form class="form" style="${`--form-column-count: ${this.columnCount}`}">
        ${(_a = this.elements) === null || _a === void 0 ? void 0 : _a.map(element => element === null || element === void 0 ? void 0 : element.render(this.value[element.name], {
            onChange: value => this.onChange(element.name, value),
            onValidityChange: isValid => this.onValidityChange(element.name, isValid),
        }))}
      </form>
    `;
    }
}
WcesFormBuilder.styles = [
    css `
      *,
      *::before,
      *::after {
        padding: 0;
        margin: 0;
        box-sizing: border-box;
      }
      .form {
        display: grid;
        grid-template-columns: repeat(var(--form-column-count, 1), 1fr);
        grid-gap: 1rem;
        grid-auto-columns: 1fr;
        grid-auto-rows: max-content;
      }
      .field {
        width: 100%;
      }
    `,
];
__decorate([
    property({ type: Object })
], WcesFormBuilder.prototype, "param", void 0);
__decorate([
    property({ type: Number })
], WcesFormBuilder.prototype, "columnCount", void 0);
__decorate([
    property({ type: Object })
], WcesFormBuilder.prototype, "_value", void 0);
__decorate([
    property({ type: Object })
], WcesFormBuilder.prototype, "value", null);
__decorate([
    property({ type: Object })
], WcesFormBuilder.prototype, "_valid", void 0);
//# sourceMappingURL=WcesFormBuilder.js.map