import { html } from 'lit-html';
import '../wces-form-builder.js';
import './native-form-builder.js';
import '../wces-material-form.js';
export default {
    title: 'wces-form-builder',
};
export const SimpleUsage = () => html ` <wces-form-builder></wces-form-builder> `;
export const WithNativeCatalog = () => {
    const param = {
        name: 'myForm',
        type: 'form',
        options: [
            {
                name: 'firstname',
                type: 'text',
                displayName: 'Firstname',
                required: true,
                span: 2,
                options: {
                    placeholder: 'Firstname',
                    minlength: 3,
                },
            },
            {
                name: 'middlename',
                type: 'text',
                displayName: 'Middlename',
                options: {
                    placeholder: 'Middlename',
                },
            },
            {
                name: 'lastname',
                type: 'text',
                displayName: 'Lastname',
                options: {
                    placeholder: 'Lastname',
                    minlength: 3,
                },
            },
        ],
    };
    const value = {
        firstname: 'Bob',
        lastname: 'Popovitch',
        middlename: 'Slovodan',
    };
    return html `
    <native-form-builder
      .param="${param}"
      .value="${value}"
    ></native-form-builder>
  `;
};
export const WithMaterialElements = () => {
    const param = {
        name: 'myForm',
        type: 'form',
        options: [
            {
                name: 'firstname',
                type: 'text',
                displayName: 'Firstname',
                required: true,
                span: 2,
                options: {
                    placeholder: 'Firstname',
                    minlength: 3,
                    maxLength: 30,
                    charCounter: true,
                    outlined: true,
                },
            },
            {
                name: 'middlename',
                type: 'text',
                displayName: 'Middlename',
                options: {
                    placeholder: 'Middlename',
                    outlined: true,
                },
            },
            {
                name: 'lastname',
                type: 'text',
                displayName: 'Lastname',
                options: {
                    placeholder: 'Lastname',
                    minlength: 3,
                    outlined: true,
                },
            },
            {
                name: 'birthday',
                type: 'text',
                displayName: 'Birthday',
                options: {
                    type: 'date',
                    outlined: true,
                },
            },
            {
                name: 'children',
                type: 'text',
                displayName: 'Number of children',
                options: {
                    type: 'number',
                    min: 0,
                    max: 50,
                    outlined: true,
                },
            },
            {
                name: 'gender',
                type: 'select',
                displayName: 'Gender',
                required: true,
                options: {
                    outlined: true,
                    options: [
                        { name: 'M', value: 'M' },
                        { name: 'F', value: 'F' },
                    ]
                },
            },
        ],
    };
    const value = {
        firstname: 'Bob',
        lastname: 'Popovitch',
        middlename: 'Slovodan',
        gender: 'M'
    };
    return html `
    <wces-material-form
      .param="${param}"
      .value="${value}"
    ></wces-material-form>
  `;
};
//# sourceMappingURL=index.stories.js.map